@@ -1,12 +1,12 @@
 context("plot_throughtime")
 
-a <- plot_throughtime('phylogeny', 300, key = "hello")
-b <- plot_throughtime(list('drosophila','monkey'), 100, key = "hello")
-c <- plot_throughtime(list('drosophila','flower'), 100, key = "hello")
+a <- plot_throughtime('phylogeny', 300)
+b <- plot_throughtime(list('drosophila','monkey'), 100)
+c <- plot_throughtime(list('drosophila','flower'), 100)
 
 test_that("plot_throughtime returns the correct class", {
   expect_is(a, "ggplot")
   expect_is(b, "ggplot")
   expect_is(c, "ggplot")
   expect_is(a$data, "data.frame")
-})
\ No newline at end of file
+})
